(function (Drupal, drupalSettings) {
  /**
   * Fetches activity from a URL and renders the results.
   */
  function checkAccess(forkId) {
    const urlParams = new URLSearchParams();
    urlParams.append('fork_id', forkId);
    return fetch(
      `${drupalSettings.path.baseUrl}drupalorg/issue-fork/check-access?${
        urlParams
      }`,
    ).then((response) => response.json());
  }

  Drupal.behaviors.forkCheckAccess = {
    async attach(context, settings) {
      // Check access to the different forks listed, if any.
      const forksContext = once('forks', 'body', context);
      if (forksContext.length) {
        const internalButtons = document.querySelectorAll(
          '.forks-management .button',
        );
        internalButtons.forEach(function (internalButton) {
          if (
            internalButton.classList.contains('request-access') ||
            internalButton.type === 'submit'
          ) {
            internalButton.addEventListener('click', function (e) {
              if (internalButton.type === 'submit') {
                internalButton.value = Drupal.t('Creating fork...');
              } else {
                internalButton.innerHTML = Drupal.t('Requesting access...');
              }
              internalButton.classList.add('is-disabled');
            });
          }
        });

        const forks = document.querySelectorAll('.fork');
        if (forks.length) {
          Promise.all(
            Array.from(forks).map((fork) => checkAccess(fork.dataset.forkId)),
          )
            .then((resultsArray) => {
              resultsArray.forEach((result) => {
                if (result.access) {
                  const requestAccessLink = document.querySelector(
                    `.fork[data-fork-id="${result.fork_id}"] .request-access`,
                  );
                  requestAccessLink.innerHTML = Drupal.t('Access granted');
                  // eslint-disable-next-line no-script-url
                  requestAccessLink.href = 'javascript: void(0)';
                  requestAccessLink.classList.add('is-disabled');
                }
              });
            })
            .catch((error) => {
              // console.log(error);
            });
        }
      }
    },
  };
})(Drupal, drupalSettings);
